# HG changeset patch
# User Marco Lizza <marco.lizza@gmail.com>
# Date 1276532028 -7200
# Node ID e82ba95ff9536cc6838c26384d16f1d5c55f1b6b
# Parent  bb682f6ded4c446e29c08d645a0d4cc5ec322e90
shellext: fixed method "GetCommandString()" for sub-menu root-item

diff -r bb682f6ded4c -r e82ba95ff953 win32/shellext/CShellExtCMenu.cpp
--- a/win32/shellext/CShellExtCMenu.cpp	Mon Jun 14 18:12:02 2010 +0200
+++ b/win32/shellext/CShellExtCMenu.cpp	Mon Jun 14 18:13:48 2010 +0200
@@ -26,6 +26,8 @@
     UINT idCmd;
 };
 
+const std::wstring TortoiseHgMenuEntryString = L"TortoiseHg";
+
 // According to http://msdn.microsoft.com/en-us/library/bb776094%28VS.85%29.aspx
 // the help texts for the commands should be reasonably short (under 40 characters)
 
@@ -106,6 +108,9 @@
     {"shellconf",   L"Explorer Extension Settings",
                     L"Configure Explorer extension",
                     "settings_repo.ico", 0},
+    {"tortoisehg",  TortoiseHgMenuEntryString,
+                    L"Tortoise Hg",
+                    "hg.ico", 0},
 
     /* Add new items here */
 
@@ -333,8 +338,23 @@
         hMenu, indexMenu, idCmd, prefix + md.menuText, md.iconName);
 }
 
+void InsertSubMenuItemByName(
+    HMENU hMenu, HMENU hSubMenu, const std::string& name, UINT indexMenu,
+    UINT idCmd, UINT idCmdFirst)
+{
+    MenuDescriptionMap::iterator iter = MenuDescMap.find(name);
+    if (iter == MenuDescMap.end())
+    {
+        TDEBUG_TRACE("***** InsertSubMenuItemByName: can't find menu info for " << name);
+        return;
+    }
 
-const std::wstring TortoiseHgMenuEntryString = L"TortoiseHg";
+    MenuDescription md = iter->second;
+    AddMenuList(idCmd - idCmdFirst, name);
+    InsertSubMenuItemWithIcon2(hMenu, hSubMenu, indexMenu, idCmd,
+            md.menuText, md.iconName);
+}
+
 
 int HasTortoiseMenu(HMENU hMenu, bool& hasmenu)
 // returns -1 on error, 0 otherwise
@@ -604,8 +624,7 @@
     }
 
     TDEBUG_TRACE("  CShellExtCMenu::QueryContextMenu: adding main THG menu");
-    InsertSubMenuItemWithIcon2(hMenu, hSubMenu, indexMenu++, idCmd++,
-            TortoiseHgMenuEntryString, "hg.ico");
+    InsertSubMenuItemByName(hMenu, hSubMenu, "tortoisehg", indexMenu++, idCmd++, idCmdFirst);
 
     InsertMenu(hMenu, indexMenu++, MF_SEPARATOR | MF_BYPOSITION, 0, NULL);
 
